@@ -67,7 +67,7 @@ class Postgres_Handler:
         table_name_key = 'table_name'
         
         #Start of query string
-        query = f'SELECT * FROM "{keywords[table_name_key]}'
+        query = f'SELECT * FROM "{keywords[table_name_key]}"'
         
         if table_name_key not in keywords:
             assert("Error: table_name required as argument")
